/*==============================================================================

FICHIER     : [systools.h]

DATE        : 2005/12/0005 22:00:48

CREATEUR    : [Linux!jef]

COMMENTAIRE :

================================================================================

==============================================================================*/

#ifndef __SYSTOOLS_H__
#define __SYSTOOLS_H__

#include <sys/time.h>

typedef struct {
	struct timeval StartTime;
	struct timeval EndTime;
} Timer_t;

enum BurnTool_t {
	BURNTOOL_NONE = 0,
	BURNTOOL_K3B,
	BURNTOOL_BRASERO
};

/*@$#[systools.c] global proto. AutoProtoSigV1.1. date: 2010/05/28 22:30:23 */
#include "proto.h"
#ifdef __cplusplus
extern "C" {
#endif
int MkFifo(char *fifoName);
int DelFifo(char *fifoName);
long long FileSize64(char *fileName);
char *LLSize2Giga(long long size);
int flook(char *fname);
long long FsFree(char *fsName);
int DirExist(char *dirName);
int DirCanWrite(char *dirname);
int FileExist(char *fileName);
int IsDvdDevice(char *fileName);
FILE *my_popen(char *command, char *mode);
int my_pclose(FILE *stream);
char *Duree2String(int duree);
char *AddString2List(char *list, char *string);
char *RemoveStringFromList(char *list, char *string);
int MakeDirIfNeeded(char *path);
int IsDvdLoaded(char *device);
int StringDuree2Sec(char *string);
int IsLoopDeviceReady(char *loopDevice);
void freeDevices(GSList *list);
GSList *getDevices(void);
int GetNumCpu(void);
int CanCreateFile(char *dirName);
char *GetMkIsoTool(void);
char *GetEnv(char *evKey, char *defValue);
Timer_t *StartTimer(void);
void StopTimer(Timer_t *timer);
double ElapsedTimer(Timer_t *timer);
void FreeTimer(Timer_t *timer);
long long CpuPhysMemSize(void);
int BurnTool(void);
int BurnIsoFile(int tool, char *device, char *isoFile);
int BurnVideoDir(int tool, char *device, char *videoDir);
#ifdef __cplusplus
}
#endif
/*@$% end of AutoProtoSigV1.1 (Dont remove this line) []*/

#endif	/* __SYSTOOLS_H__ */

